==> wormux-0.8.5.tar.bz2: wormux-0.8.5/src/weapon/teleportation.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2009 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Teleportation.
 *****************************************************************************/

#ifndef TELEPORTATION_H
#define TELEPORTATION_H

#include "weapon.h"

class WeaponConfig;

class Teleportation : public Weapon
{
  private:
    bool target_chosen;
    uint animation_duration;
    Point2i src, dst;
  protected:
    bool p_Shoot();
    void p_Select();
    void Refresh();
  public:
    Teleportation();
    void Draw() { if (!IsInUse()) Weapon::Draw(); };
    void ChooseTarget(Point2i mouse_pos);
    bool IsInUse() const;
    WeaponConfig& cfg();

    void UpdateTranslationStrings();
    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
};

#endif /* TELEPORTATION_H */

==> wormux_0.9.2.1.orig.tar.bz2: wormux-0.9.2.1/src/weapon/teleportation.h <==
/******************************************************************************
 *  Wormux is a convivial mass murder game.
 *  Copyright (C) 2001-2010 Wormux Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 ******************************************************************************
 * Teleportation.
 *****************************************************************************/

#ifndef TELEPORTATION_H
#define TELEPORTATION_H

#include "weapon.h"

class WeaponConfig;

class Teleportation : public Weapon
{
  private:
    bool target_chosen;
    uint animation_duration;
    Point2i src, dst;
    bool done;
  protected:
    bool p_Shoot();
    void p_Select();
    void Refresh();
    virtual bool ShouldBeVisible();
  public:
    Teleportation();
    void ChooseTarget(Point2i mouse_pos);
    virtual void StartShooting() {}
    virtual void StopShooting() {}
    WeaponConfig& cfg();

    void UpdateTranslationStrings();
    std::string GetWeaponWinString(const char *TeamName, uint items_count ) const;
};

#endif /* TELEPORTATION_H */
